[![Travis CI status](https://api.travis-ci.org/ascoderu/mkwvconf.svg?branch=master)](https://travis-ci.org/ascoderu/mkwvconf)

This is a fork of mkwvconf modified to work on Python 2.7 and later

The original mkwvconf lives here: https://github.com/schuay/mkwvconf
